declare type TranslationValue = string | TranslationObject;
interface TranslationObject {
    [x: string]: TranslationValue;
}
export default class I18n {
    translations: TranslationObject;
    locale: string;
    constructor();
    setTranslations(translations: TranslationObject): void;
    setLocale(locale: string): void;
    /**
     * Leverages Intl.NumberFormat for currency formatting
     */
    formatNumber(num: number, style?: string, currency?: string): string;
    /**
     * Retrieves a key from the translations object.
     */
    getKey(path: string): TranslationObject | string;
    /**
     * Translate a key
     * Interpolate values with %{name}
     *
     * Examples:
     *
     * t('foo.bar') => 'Bar'
     * t('zemba.fleiba', {num: 3 }) => 'Zemba 3 Fleiba!'
     */
    t(path: string, opts?: {
        [key: string]: any;
    }): string;
    /**
     * Translate singular o plural copies
     * Options must contain `count`
     *
     * Examples:
     *
     * tp('beer', { count: 3 }) => '3 beers'
     */
    tp(path: string, opts: {
        [key: string]: any;
    }): string;
    /**
     * Conditional copies, made easy.
     * Provide a path and then options, like classNames
     *
     * Example:
     *
     *   tx('fleiba.zemba', user.get('role'))
     */
    tx(path: string, variable: string, opts?: {
        [key: string]: any;
    }): string;
}
export {};
